@@ -1,10 +1,8 @@
-context("freq")
-
 test_that("frequency conversions return as expected", {
   x <- "a e4 a4 e5 a5"
   y <- pitch_freq(x)
   expect_true(all(y - c(220, 329.6276, 440, 659.2551, 880) < 1e-4))
-  expect_identical(as_noteworthy(x), freq_pitch(y, collapse = TRUE) %>%
+  expect_identical(as_noteworthy(x), freq_pitch(y, collapse = TRUE) |>
                      as_integer_octaves())
   expect_identical(pitch_semitones(x), as.integer(c(57, 64, 69, 76, 81)))
   expect_true(all(abs(freq_semitones(y) - c(57, 64, 69, 76, 81)) < 0.0001))
